########################################################################
### December 16, 2021
### Statistical analyses & data visualizations in the manuscript
########################################################################
#-------------------------------------------------#
# Prerequisites
#-------------------------------------------------#
getwd()
### Load required packages
library(lmerTest)
library(Rmisc)
library(lattice)
library(tidyverse)
library(ggplot2)

####################################################
# Experiment 1: testing the First-Person Constraint
####################################################
### Import dataset 
read.csv("exp1_data_with_truth_value")

#-------------------------------------------------------------------#
# Comparison between the children who were exposed to mora(w)-u and 
# children who were not exposed to mora(w)-u
#-------------------------------------------------------------------#
### Run the logistic regression analysis
## Response variable: accuracy (correct = 1, incorrect = 0)
## Predictor variables: verb_type (age-ru, kure-ru), group (with mora(w)-u vs. without mora(w)-u)
subset_give = subset (exp1_data_with_truth_value, verb_type!="mora(w)-u")
subset_child = subset (subset_give, adults_children != "adults")
View(subset_child)

mod_child1 <- glm(accuracy ~ 1 + verb_type * group,
                  subset_child, family="binomial")
summary(mod_child1)
## Results of this analysis are mentioned at the end of 5.1 and footnote 14

#-------------------------------------------------#
# Show the results from adults & children
#-------------------------------------------------#
### Make verb_type and adults_children as factors
exp1_data_with_truth_value$verb_type <- as.factor(exp1_data_with_truth_value$verb_type)
exp1_data_with_truth_value$adults_children <- as.factor(exp1_data_with_truth_value$adults_children)
exp1_data_with_truth_value$target_answer <- as.factor(exp1_data_with_truth_value$target_answer)

### Overall results
summarySE(exp1_data_with_truth_value, measurevar="truth_value", 
          groupvars=c("verb_type", "adults_children", "target_answer"))

## The results are shown in Figure 3

########## Create a plot #########################
exp1_data_with_truth_value$verb_type <- 
  factor(exp1_data_with_truth_value$verb_type, levels=c("age-ru","kure-ru","mora(w)-u"))
exp1_data_with_truth_value$target_answer <- 
  factor(exp1_data_with_truth_value$target_answer, levels=c("TRUE","FALSE"))

###  SD, SE, Confidence Interval (CI), condition
Data_fig <- 
  summarySE(exp1_data_with_truth_value, measurevar="truth_value", 
            groupvars=c("adults_children", "verb_type", "target_answer"))

### by group (adults vs. children) & by verb type
ggplot(Data_fig, aes(x=verb_type, y=truth_value*100)) + 
  geom_point(stat="identity", size = 4, aes(colour=factor(verb_type), 
                                            shape=factor(verb_type))) + 
  geom_errorbar(aes(ymin=truth_value*100-se*100, ymax=truth_value*100+se*100, 
                    colour=factor(verb_type)), 
                width=0.4) +
  scale_y_continuous(limits=c(0,110), breaks=seq(0,110,by=20)) +
  labs(x="Verb type", y = "% of YES responses") +
  theme(legend.position = "bottom", text = element_text(size = 17), 
        legend.title = element_blank()) +
  facet_grid(target_answer ~ adults_children) +
  scale_colour_manual(values=c("#009900", "#0066CC", "#FF9900")) +
  scale_x_discrete(labels = NULL)

ggsave("Figure3.pdf", dpi = 1200)

#-------------------------------------------------#
# By-group analyses
#-------------------------------------------------#
############# L1 children ###########################
### Make a subset of children
data_child = subset (exp1_data_with_truth_value, adults_children!="adults")

## Overall results in L1 children
summarySE(data_child, measurevar="truth_value", 
          groupvars=c("verb_type", "age_group", "target_answer"))

## The results are shown in Figure 4

### Run the logistic regression analysis
## Response variable: accuracy (correct = 1, incorrect = 0)
## Predictor variables: verb_type (age-ru, kure-ru, mora(w)-u), age (continuous)
mod_child1 <- glm(accuracy ~ 1 + verb_type * age,
                  data_child, family="binomial")
summary(mod_child1)
## Results of this analysis are shown in Table 7

###### Create a plot by age group
data_child$verb_type <- 
  factor(data_child$verb_type, levels=c("age-ru","kure-ru", "mora(w)-u"))
data_child$target_answer <- 
  factor(data_child$target_answer, levels=c("TRUE","FALSE"))

###  SD, SE, Confidence Interval (CI), condition
Data_fig_child <- 
  summarySE(data_child, measurevar="truth_value", groupvars=c("verb_type", "age_group", "target_answer"))

### Create a plot
ggplot(Data_fig_child, aes(x=verb_type, y=truth_value*100)) + 
  geom_point(stat="identity", size = 4, aes(colour=factor(verb_type), 
                                            shape=factor(verb_type))) +  
  geom_errorbar(aes(ymin=truth_value*100-se*100, ymax=truth_value*100+se*100, 
                    colour=factor(verb_type)), 
                width=0.4) +
  scale_y_continuous(limits=c(0,110), breaks=seq(0,110,by=20)) +
  labs(x="Verb type", y = "% of YES responses") +
  theme(legend.position = "bottom", text = element_text(size = 17), 
        legend.title = element_blank()) +
  scale_x_discrete(labels = NULL) +
  facet_grid(target_answer ~ age_group) +
  scale_colour_manual(values=c("#009900", "#0066CC", "#FF9900")) 

ggsave("Figure4.pdf", dpi = 1200)

#-------------------------------------------------#
# Individual analysis of kure-ru
#-------------------------------------------------#
############# Calculate each participant's accurate responses with kure-ru
##### 1. Filter kure-ru condition
kureru <- filter(data_child, verb_type =="kure-ru")
head(kureru)

##### 2. Calculate the number of accurate responses per participant
agg_kureru_accuracy <- aggregate(kureru$accuracy, 
                                 by = list(participant = kureru$participant), FUN = sum) 
accuracy_new <- agg_kureru_accuracy %>% rename("accurate_response_time_with_kureru" = "x")

agg_kureru_age <- aggregate(kureru$age, 
                            by = list(participant = kureru$participant), FUN = mean)
age_new <- agg_kureru_age %>% rename("age" = "x")

#### 3. Combine the above sparate data
combine <- merge(accuracy_new, age_new,by="participant")
View(combine)

####### Create a plot for individual analysis #################################
ggplot(linear0, aes(x=age, y=accurate_response_time_with_kureru)) + 
  geom_point(size=5,position=position_jitter(h=0.3, w=0.3), alpha = 0.5,
            colour = "#0066CC", shape = "square")+ 
  labs(x="Age", y = "Number of accurate responses with kure-ru")+
  scale_x_continuous(limits=c(48,84), breaks=c(48,60,72,84), 
                     labels=c("4;0","5;0","6;0","7;0")) +
  scale_y_continuous(limits=c(-1,5), breaks=c(0,1,2,3,4), 
                     labels=c("0","1","2","3","4")) + 
  theme(text = element_text(size=12))

ggsave("Figure5_dpi1200.png", dpi = 1200)

#########################################################
# Experiment 2: testing the Reflexive Binding Constraint
#########################################################
### Import dataset 
read.csv("exp2_data")
View(exp2_data)

#-------------------------------------------------#
# Show the results from adults & children
#-------------------------------------------------#
### Make sentence_type and story_type as factors
exp2_data$sentence_type <- as.factor(exp2_data$sentence_type)
exp2_data$story_type <- as.factor(exp2_data$story_type)

### Overall result
summarySE(exp2_data, measurevar="answer", 
          groupvars=c("adult_child", "sentence_type", "story_type"))
## the results are shown in Figure 8

########## Create a plot #########################
exp2_data$story_type2 <- 
  factor(exp2_data$story_type2, levels=c("local-true stories","LD-true stories"))

exp2_data$sentence_type <- 
  factor(exp2_data$sentence_type, levels=c("no-empathy-verb","age-ru","kure-ru"))

###  SD, SE, Confidence Interval (CI), condition
Data_fig_binding <- 
  summarySE(exp2_data, measurevar="answer", groupvars=c("adult_child", "sentence_type", "story_type2"))

### by group & by give verb
ggplot(Data_fig_binding, aes(x=sentence_type, y=answer*100)) + 
  geom_point(stat="identity", size = 4, aes(colour=factor(sentence_type), 
                                            shape=factor(sentence_type))) +  
  geom_errorbar(aes(ymin=answer*100-se*100, ymax=answer*100+se*100, 
                    colour=factor(sentence_type)), 
                width=0.4) +
  scale_y_continuous(limits=c(0,110), breaks=seq(0,110,by=20)) +
  labs(x="Verb type", y = "% of YES responses") +
  theme(legend.position = "bottom", text = element_text(size = 14.3), 
        legend.title = element_blank()) +
  facet_grid(story_type2 ~ adult_child) +
  scale_x_discrete(labels = NULL) +
  scale_colour_manual(values=c("#FF3399", "#009900", "#0066CC")) +
  scale_shape_manual(values=c(18, 16, 17))

ggsave("Figure8.png", dpi = 1200)

#-------------------------------------------------#
# By-group analyses
#-------------------------------------------------#
############# L1 adults ###########################
### Make a subset of adults
subset_adult = subset (exp2_data, adult_child!="children (n = 26)")
View(subset_adult)

### Run a logistic regression analysis
## Response variable: answer (true = 1, false = 0)
## Predictor variables: sentence_type (no-empathy-verb, age-ru, kure-ru), story_type (local vs. LD)
## Random effects: subject as a random intercept
subset_adult$story_type <- 
  factor(subset_adult$story_type, levels=c("local_true","LD_true")) # specify "local_true" as a reference level

mod_adult <- glmer(answer ~ 1 + sentence_type * story_type + 
                     (1 | subject), subset_adult, family="binomial")
summary(mod_adult)

## The results are shown in Table 9

############# L1 children ###########################
### Make a subset of children
subset_child = subset (exp2_data, adult_child!="adults (n = 27)")
View(subset_child)

### Overall result
summarySE(subset_child, measurevar="answer", 
          groupvars=c("age_group", "sentence_type", "story_type"))

### Run a logistic regression analysis
## Response variable: answer (true = 1, false = 0)
## Predictor variables: sentence_type (no-empathy-verb, age-ru, kure-ru), story_type (local vs. LD), Age (continuous)
subset_child$story_type <- 
  factor(subset_child$story_type, levels=c("local_true","LD_true"))

mod_child <- glm(answer ~ 1 + sentence_type * story_type * age,
                 subset_child, family="binomial")
summary(mod_child)
## The results are shown in Table 10

###### Create a plot by age group
subset_child$story_type <- 
  factor(subset_child$story_type, levels=c("local-true stories","LD-true stories"))
subset_child$sentence_type <- 
  factor(subset_child$sentence_type, levels=c("no-empathy-verb","age-ru","kure-ru"))

###  SD, SE, Confidence Interval (CI), condition
Data_fig_binding_child <- 
  summarySE(subset_child, measurevar="answer", groupvars=c("sentence_type", "story_type2", "age_group"))

### Create a plot
ggplot(Data_fig_binding_child, aes(x=sentence_type, y=answer*100)) + 
  geom_point(stat="identity", size = 4, aes(colour=factor(sentence_type), 
                                            shape=factor(sentence_type))) + 
  geom_errorbar(aes(ymin=answer*100-se*100, ymax=answer*100+se*100, 
                    colour=factor(sentence_type)), 
                width=0.4) +
  scale_y_continuous(limits=c(-5,110), breaks=c(0,20,40,60,80,100)) +
  labs(x="Verb type", y = "% of YES responses") +
  theme(legend.position = "bottom", text = element_text(size = 12), 
        legend.title = element_blank()) +
  facet_grid(story_type2 ~ age_group) +
  scale_x_discrete(labels = NULL) +
  scale_colour_manual(values=c("#FF3399", "#009900", "#0066CC")) 

ggsave("Figure9.png", dpi = 1200)

#-------------------------------------------------#
# Individual analysis of kure-ru
#-------------------------------------------------#
############### Calculate the number of responses that children gave long-distance interpretations with kure-ru
##### 1. Filter kure-ru condition
kureru2 <- filter(subset_child, sentence_type =="kure-ru")
View(kureru2)

##### 2. Calculate the number of LD interpretations per participant
agg_kureru_local <- aggregate(kureru2$LD_as_1_opposite_from_column_judgment, 
                              by = list(subject = kureru2$subject), FUN = sum) 
accuracy_new2 <- agg_kureru_local %>% rename("LD_reading_with_kureru" = "x")

agg_kureru_age2 <- aggregate(kureru2$age, 
                             by = list(subject = kureru2$subject), FUN = mean)
age_new2 <- agg_kureru_age2 %>% rename("age" = "x")

#### 3. Combine the above sparate data
combine2 <- merge(accuracy_new2, age_new2,by="subject")
View(combine2)

####### Create a plot for individual results #################################
ggplot(combine2, aes(x=age, y=LD_reading_with_kureru)) + 
  geom_point(size=5,position=position_jitter(h=0.2, w=0.2), 
             alpha = 0.5, colour = "#0066CC", shape = "square")+
  labs(x="Age", y = "Number of accurate responses with kure-ru")+
  scale_y_continuous(limits=c(-1,5), breaks=c(0,1,2,3,4), 
                     labels=c("0","1","2","3","4")) + 
  scale_x_continuous(limits=c(48,84), breaks=c(48,60,72,84), 
                     labels=c("4;0","5;0","6;0","7;0")) + 
  theme(text = element_text(size=12)) 

ggsave("Figure10_dpi1200.png", dpi = 1200)







